# DashboardDeutschland
Auf https://www.dashboard-deutschland.de bietet das Statistische Bundesamt DESTATIS einen Überblick zu gesellschaftlich und wirtschaftlich relevanten Daten aus unterschiedlichen Themenbereichen. Diese werden durch Grafiken und Texte ergänzt und regelmäßig aktualisiert. Damit soll eine Möglichkeit geboten werden, aktuelle Kennzahlen und deren Entwicklung übersichtlich darzustellen.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 0.1.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://github.com/AndreasFischer1985/dashboard-deutschland-api](https://github.com/AndreasFischer1985/dashboard-deutschland-api)

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

```sh
pip install deutschland[DashboardDeutschland]
```

### poetry install

```sh
poetry add deutschland -E DashboardDeutschland
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

## Usage

Import the package:
```python
from deutschland import DashboardDeutschland
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
from deutschland import DashboardDeutschland
from pprint import pprint
from deutschland.DashboardDeutschland.api import geo_api
from deutschland.DashboardDeutschland.model.geo import Geo
# Defining the host is optional and defaults to https://www.dashboard-deutschland.de
# See configuration.py for a list of all supported configuration parameters.
configuration = DashboardDeutschland.Configuration(
    host = "https://www.dashboard-deutschland.de"
)



# Enter a context with an instance of the API client
with DashboardDeutschland.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = geo_api.GeoApi(api_client)

    try:
        # Zugriff auf Geojson-Daten zu Deutschland und den Ländern
        api_response = api_instance.geo()
        pprint(api_response)
    except DashboardDeutschland.ApiException as e:
        print("Exception when calling GeoApi->geo: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://www.dashboard-deutschland.de*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*GeoApi* | [**geo**](docs/GeoApi.md#geo) | **GET** /geojson/de-all.geo.json | Zugriff auf Geojson-Daten zu Deutschland und den Ländern
*GetApi* | [**get**](docs/GetApi.md#get) | **GET** /api/dashboard/get | Zugriff auf alle gültigen Einträge des id-Parameters
*IndicatorsApi* | [**indicators**](docs/IndicatorsApi.md#indicators) | **GET** /api/tile/indicators | Zugriff auf unterschiedliche Indikatoren


## Documentation For Models

 - [Geo](docs/Geo.md)
 - [GeoCrs](docs/GeoCrs.md)
 - [GeoCrsProperties](docs/GeoCrsProperties.md)
 - [Get](docs/Get.md)
 - [GetCategory](docs/GetCategory.md)
 - [GetLayoutTiles](docs/GetLayoutTiles.md)
 - [Indicators](docs/Indicators.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author

andreasfischer1985@web.de


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in DashboardDeutschland.apis and DashboardDeutschland.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from deutschland.DashboardDeutschland.api.default_api import DefaultApi`
- `from deutschland.DashboardDeutschland.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
from deutschland import DashboardDeutschland
from deutschland.DashboardDeutschland.apis import *
from deutschland.DashboardDeutschland.models import *
```

